/*
 * Simulator of microcontrollers (avrcl.h)
 *
 * Copyright (C) 1999,99 Drotos Daniel, Talker Bt.
 * 
 * To contact author send email to drdani@mazsola.iit.uni-miskolc.hu
 *
 */

/* This file is part of microcontroller simulator: ucsim.

UCSIM is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

UCSIM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with UCSIM; see the file COPYING.  If not, write to the Free
Software Foundation, 59 Temple Place - Suite 330, Boston, MA
02111-1307, USA. */
/*@1@*/

#ifndef AVRCL_HEADER
#define AVRCL_HEADER

#include "uccl.h"


/*
 * Base type of AVR microcontrollers
 */

class cl_avr: public cl_uc
{
public:
  cl_avr(class cl_sim *asim);
  virtual int init(void);
  virtual char *id_string(void);

  virtual long get_mem_size(enum mem_class type);
  virtual int get_mem_width(enum mem_class type);
  virtual void mk_hw_elements(void);

  virtual struct dis_entry *dis_tbl(void);
  virtual struct name_entry *sfr_tbl(void);
  virtual struct name_entry *bit_tbl(void);

  virtual int exec_inst(bool use_breaks);
  virtual int ijmp(void);
  virtual int eijmp(void);
  virtual int icall(void);
  virtual int eicall(void);
  virtual int ret(void);
  virtual int reti(void);
  virtual int lmp(void);
  virtual int elmp(void);
  virtual int smp(void);
  virtual int esmp(void);
  virtual int sec(void);
  virtual int clc(void);
  virtual int sen(void);
  virtual int cln(void);
  virtual int sez(void);
  virtual int clz(void);
  virtual int sei(void);
  virtual int cli(void);
  virtual int ses(void);
  virtual int cls(void);
  virtual int sev(void);
  virtual int clv(void);
  virtual int set(void);
  virtual int clt(void);
  virtual int seh(void);
  virtual int clh(void);
  virtual int nop(void);
  virtual int sleep(void);
  virtual int wdr(void);
};


#endif

/* End of avrcl.h */
